==> openGion6.9.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         NUMBER   (    5 )       DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       VARCHAR2 (    1 )                   NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    VARCHAR2 ( 4000 )                                       /*  50 ﾃｷｽﾄ     */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員 */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01;

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         NUMBER   (    5 )       DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       VARCHAR2 (    1 )                   NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    VARCHAR2 ( 4000 )                                       /*  50 ﾃｷｽﾄ     */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者   */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
